@@ -3,9 +3,7 @@
 namespace Icinga\Module\Director\Controllers;
 
 use Icinga\Module\Director\Web\Tabs\MainTabs;
-use Icinga\Module\Director\Web\Widget\HealthCheckPluginOutput;
 use Icinga\Module\Director\Dashboard\Dashboard;
-use Icinga\Module\Director\Health;
 use Icinga\Module\Director\Web\Controller\ActionController;
 use Icinga\Module\Director\Web\Form\DbSelectorForm;
 
@@ -35,7 +33,15 @@ class DashboardController extends ActionController
             $this->setAutorefreshInterval(10);
         }
 
-        $mainDashboards = ['Objects', 'Alerts', 'Automation', 'Deployment', 'Director', 'Data'];
+        $mainDashboards = [
+            'Objects',
+            'Alerts',
+            'Branches',
+            'Automation',
+            'Deployment',
+            'Director',
+            'Data',
+        ];
         $this->setTitle($this->translate('Icinga Director - Main Dashboard'));
         $names = $this->params->getValues('name', $mainDashboards);
         if (! $this->params->has('name')) {
