@@ -2,14 +2,16 @@
 
 namespace Icinga\Module\Director\Controllers;
 
+use gipfl\IcingaWeb2\Url;
 use Icinga\Data\Filter\Filter;
 use Icinga\Data\Filter\FilterChain;
 use Icinga\Data\Filter\FilterExpression;
+use Icinga\Module\Director\DirectorObject\Automation\ExportInterface;
 use Icinga\Module\Director\Forms\IcingaAddServiceForm;
 use Icinga\Module\Director\Forms\IcingaAddServiceSetForm;
 use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Web\Controller\ObjectsController;
-use dipl\Html\Link;
+use gipfl\IcingaWeb2\Link;
 
 class HostsController extends ObjectsController
 {
@@ -47,6 +49,31 @@ class HostsController extends ObjectsController
         ));
     }
 
+    public function edittemplatesAction()
+    {
+        parent::editAction();
+
+        $objects = $this->loadMultiObjectsFromParams();
+        $names = [];
+        /** @var ExportInterface $object */
+        foreach ($objects as $object) {
+            $names[] = $object->getUniqueIdentifier();
+        }
+
+        $url = Url::fromPath('director/basket/add', [
+            'type'  => 'HostTemplate',
+        ]);
+
+        $url->getParams()->addValues('names', $names);
+
+        $this->actions()->add(Link::create(
+            $this->translate('Add to Basket'),
+            $url,
+            null,
+            ['class' => 'icon-tag']
+        ));
+    }
+
     public function addserviceAction()
     {
         $this->addSingleTab($this->translate('Add Service'));
