@@ -3,6 +3,7 @@
 namespace Icinga\Module\Director\Controllers;
 
 use Exception;
+use gipfl\Web\Widget\Hint;
 use Icinga\Module\Director\Db\Migrations;
 use Icinga\Module\Director\Forms\ApplyMigrationsForm;
 use Icinga\Module\Director\Forms\KickstartForm;
@@ -19,7 +20,7 @@ class IndexController extends DashboardController
 
             if ($migrations->hasSchema()) {
                 if (!$this->hasDeploymentEndpoint()) {
-                    $this->showKickstartForm(false);
+                    $this->showKickstartForm();
                 }
             }
 
@@ -30,25 +31,34 @@ class IndexController extends DashboardController
                         ->handleRequest()
                 );
             } elseif ($migrations->hasBeenDowngraded()) {
-                $this->content()->add(Html::tag('p', ['class' => 'state-hint warning'], sprintf($this->translate(
+                $this->content()->add(Hint::warning(sprintf($this->translate(
                     'Your DB schema (migration #%d) is newer than your code base.'
                     . ' Downgrading Icinga Director is not supported and might'
                     . ' lead to unexpected problems.'
                 ), $migrations->getLastMigrationNumber())));
             }
 
-            parent::indexAction();
+            if ($migrations->hasSchema()) {
+                parent::indexAction();
+            } else {
+                $this->addTitle(sprintf(
+                    $this->translate('Icinga Director Setup: %s'),
+                    $this->translate('Create Schema')
+                ));
+                $this->addSingleTab('Setup');
+            }
         } else {
+            $this->addTitle(sprintf(
+                $this->translate('Icinga Director Setup: %s'),
+                $this->translate('Choose DB Resource')
+            ));
+            $this->addSingleTab('Setup');
             $this->showKickstartForm();
         }
     }
 
-    protected function showKickstartForm($showTab = true)
+    protected function showKickstartForm()
     {
-        if ($showTab) {
-            $this->addSingleTab($this->translate('Kickstart'));
-        }
-
         $form = KickstartForm::load();
         if ($name = $this->getPreferredDbResourceName()) {
             $form->setDbResourceName($name);
