@@ -48,7 +48,7 @@ class SyncruleController extends ActionController
      */
     public function indexAction()
     {
-        $this->setAutoRefreshInterval(10);
+        $this->setAutorefreshInterval(10);
         $rule = $this->requireSyncRule();
         $this->tabs(new SyncRuleTabs($rule))->activate('show');
         $ruleName = $rule->get('rule_name');
@@ -94,7 +94,7 @@ class SyncruleController extends ActionController
                 break;
             case 'in-sync':
                 $c->add(Html::tag('p', null, sprintf(
-                    $this->translate('This Sync Rule was last found to by in Sync at %s.'),
+                    $this->translate('This Sync Rule was last found to be in Sync at %s.'),
                     $rule->get('last_attempt')
                 )));
                 /*
@@ -380,10 +380,7 @@ class SyncruleController extends ActionController
     protected function firstNames($objects, $max = 50)
     {
         $names = [];
-        $list = new UnorderedList();
-        $list->addAttributes([
-            'style' => 'list-style-type: none; marign: 0; padding: 0',
-        ]);
+        $list = new UnorderedList([], ['class' => 'unordred-list']);
         $total = count($objects);
         $i = 0;
         PrefetchCache::forget();
@@ -464,7 +461,7 @@ class SyncruleController extends ActionController
     {
         $list = new UnorderedList();
         foreach ($properties as $property => $cnt) {
-            $list->addItem("${cnt}x $property");
+            $list->addItem("{$cnt}x $property");
         }
 
         return $list;
@@ -517,7 +514,6 @@ class SyncruleController extends ActionController
             if ($this->showNotInBranch($this->translate('Modifying Sync Rules'))) {
                 return;
             }
-
         } else {
             $this->addTitle($this->translate('Add sync rule'));
             $this->tabs(new SyncRuleTabs())->activate('add');
@@ -609,12 +605,11 @@ class SyncruleController extends ActionController
         $form = SyncPropertyForm::load()->setDb($db);
         $this->tabs(new SyncRuleTabs($rule))->activate('property');
             $this->actions()->add(new Link(
-            $this->translate('back'),
-            'director/syncrule/property',
-            ['rule_id' => $ruleId],
-            ['class' => 'icon-left-big']
-        ));
-
+                $this->translate('back'),
+                'director/syncrule/property',
+                ['rule_id' => $ruleId],
+                ['class' => 'icon-left-big']
+            ));
         if ($id = $this->params->get('id')) {
             $form->loadObject((int) $id);
             $this->addTitle(
@@ -647,7 +642,7 @@ class SyncruleController extends ActionController
      */
     public function historyAction()
     {
-        $this->setAutoRefreshInterval(30);
+        $this->setAutorefreshInterval(30);
         $rule = $this->requireSyncRule();
         $this->tabs(new SyncRuleTabs($rule))->activate('history');
         $this->addTitle($this->translate('Sync history') . ': ' . $rule->get('rule_name'));
