@@ -4,9 +4,12 @@ namespace Icinga\Module\Director\Controllers;
 
 use Icinga\Module\Director\Forms\IcingaTemplateChoiceForm;
 use Icinga\Module\Director\Web\Controller\ActionController;
+use Icinga\Module\Director\Web\Controller\BranchHelper;
 
 class TemplatechoiceController extends ActionController
 {
+    use BranchHelper;
+
     protected function checkDirectorPermissions()
     {
         $this->assertPermission('director/admin');
@@ -24,12 +27,15 @@ class TemplatechoiceController extends ActionController
 
     protected function prepare($type, $title)
     {
+        $this->addSingleTab('Choice')
+            ->addTitle($title);
         $form = IcingaTemplateChoiceForm::create($type, $this->db())
             ->optionallyLoad($this->params->get('name'))
             ->setListUrl("director/templatechoices/$type")
             ->handleRequest();
-        $this->addSingleTab('Choice')
-            ->addTitle($title)
-            ->content()->add($form);
+        if ($this->showNotInBranch($this->translate('Modifying Template Choices'))) {
+            return;
+        }
+        $this->content()->add($form);
     }
 }
