@@ -39,6 +39,19 @@ class SelfServiceSettingsForm extends DirectorForm
             ],
             'value'  => $settings->getStoredOrDefaultValue('self-service/transform_hostname')
         ]);
+        $this->addElement('select', 'resolve_parent_host', [
+            'label'       => $this->translate('Transform Parent Host to IP'),
+            'description' => $this->translate(
+                'This is only important in case your master/satellite nodes do not'
+                . ' have IP addresses as their "host" property. The Agent can be'
+                . ' told to issue related DNS lookups on it\' own'
+            ),
+            'multiOptions' => [
+                '0'   => $this->translate("Don't care, my host settings are fine"),
+                '1'   => $this->translate('My Agents should use DNS to look up Endpoint names'),
+            ],
+            'value'  => $settings->getStoredOrDefaultValue('self-service/resolve_parent_host')
+        ]);
 
         $this->addElement('extensibleSet', 'global_zones', [
             'label'       => $this->translate('Global Zones'),
