@@ -25,7 +25,7 @@ class SyncPropertyForm extends DirectorObjectForm
 
     private $dummyObject;
 
-    const EXPRESSION = '__EXPRESSION__';
+    public const EXPRESSION = '__EXPRESSION__';
 
     /**
      * @throws \Zend_Form_Exception
@@ -93,7 +93,8 @@ class SyncPropertyForm extends DirectorObjectForm
                 $this->setElementValue('use_filter', $useFilter = 'n');
             }
         } else {
-            $useFilter = strlen($this->getObject()->filter_expression) ? 'y' : 'n';
+            $expression = $this->getObject()->filter_expression;
+            $useFilter = ($expression === null || strlen($expression) === 0) ? 'n' : 'y';
             $this->setElementValue('use_filter', $useFilter);
         }
 
