@@ -8,7 +8,11 @@ class Json
 {
     public static function encode($mixed, $flags = null)
     {
-        $result = \json_encode($mixed, $flags);
+        if ($flags === null) {
+            $result = \json_encode($mixed);
+        } else {
+            $result = \json_encode($mixed, $flags);
+        }
 
         if ($result === false && json_last_error() !== JSON_ERROR_NONE) {
             throw JsonEncodeException::forLastJsonError();
