@@ -8,12 +8,15 @@ use Icinga\Exception\ConfigurationError;
 
 class Logger extends IcingaLogger
 {
-    public static function replaceRunningInstance(LogWriter $writer, $level = self::DEBUG)
+    public static function replaceRunningInstance(LogWriter $writer, $level = null)
     {
         try {
-            self::$instance
-                ->setLevel($level)
-                ->writer = $writer;
+            $instance = static::$instance;
+            if ($level !== null) {
+                $instance->setLevel($level);
+            }
+
+            $instance->writer = $writer;
         } catch (ConfigurationError $e) {
             self::$instance->error($e->getMessage());
         }
