@@ -2,6 +2,8 @@
 
 namespace Icinga\Module\Director\Dashboard\Dashlet;
 
+use Icinga\Module\Director\Auth\Permission;
+
 class KickstartDashlet extends Dashlet
 {
     protected $icon = 'gauge';
@@ -11,7 +13,7 @@ class KickstartDashlet extends Dashlet
         return $this->translate('Kickstart Wizard');
     }
 
-    public function getEscapedSummary()
+    public function getSummary()
     {
         return $this->translate(
             'This synchronizes Icinga Director to your Icinga 2 infrastructure.'
@@ -26,6 +28,6 @@ class KickstartDashlet extends Dashlet
 
     public function listRequiredPermissions()
     {
-        return array('director/admin');
+        return [Permission::ADMIN];
     }
 }
