@@ -2,14 +2,11 @@
 
 namespace Icinga\Module\Director\Dashboard\Dashlet;
 
-use DirectoryIterator;
-use Icinga\Exception\ProgrammingError;
-
 class UserObjectDashlet extends Dashlet
 {
     protected $icon = 'users';
 
-    protected $requiredStats = array('user', 'usergroup');
+    protected $requiredStats = ['user', 'usergroup'];
 
     public function getTitle()
     {
