@@ -8,6 +8,7 @@ use Icinga\Module\Director\Objects\IcingaEndpoint;
 use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Objects\IcingaZone;
 use Icinga\Module\Director\Util;
+use LogicException;
 
 class AgentWizard
 {
@@ -15,12 +16,13 @@ class AgentWizard
 
     protected $host;
 
-    protected $salt;
-
     protected $parentZone;
 
     protected $parentEndpoints;
 
+    /** @var string PKI ticket */
+    protected $ticket;
+
     public function __construct(IcingaHost $host)
     {
         $this->host = $host;
@@ -96,34 +98,32 @@ class AgentWizard
         );
     }
 
-    public function setTicketSalt($salt)
-    {
-        $this->salt = $salt;
-        return $this;
-    }
-
+    /**
+     * Get the PKI ticket
+     *
+     * @return string
+     *
+     * @throws LogicException If ticket has not been set
+     */
     protected function getTicket()
     {
-        return Util::getIcingaTicket(
-            $this->getCertName(),
-            $this->getTicketSalt()
-        );
-    }
-
-    protected function getTicketSalt()
-    {
-        if ($this->salt === null) {
-            throw new ProgrammingError('Requesting salt, but got none');
-            // TODO: No API, not yet. Pass in constructor or throw, still tbd
-            // $this->salt = $this->api()->getTicketSalt();
+        if ($this->ticket === null) {
+            throw new LogicException('Ticket is null');
         }
 
-        return $this->salt;
+        return $this->ticket;
     }
 
-    protected function getCertName()
+    /**
+     * Set the PKI ticket
+     *
+     * @param string $ticket
+     *
+     * @return $this
+     */
+    public function setTicket($ticket)
     {
-        return $this->host->getObjectName();
+        $this->ticket = $ticket;
     }
 
     protected function loadPowershellModule()
@@ -137,7 +137,7 @@ class AgentWizard
             . "\n\n"
             . 'exit Icinga2AgentModule `' . "\n    "
             . $this->renderPowershellParameters([
-                'AgentName'       => $this->getCertName(),
+                'AgentName'       => $this->host->getEndpointName(),
                 'Ticket'          => $this->getTicket(),
                 'ParentZone'      => $this->getParentZone()->getObjectName(),
                 'ParentEndpoints' => array_keys($this->getParentEndpoints()),
@@ -148,15 +148,34 @@ class AgentWizard
 
     public function renderIcinga4WindowsWizardCommand($token)
     {
-        $script = "Use-Icinga;\n"
-            . 'Start-IcingaAgentInstallWizard `' . "\n    "
+        $ifwParams = [
+            "IfW-DirectorSelfServiceKey" => [
+                "Values" => [$token],
+            ],
+            "IfW-DirectorUrl" => [
+                "Values" => [$this->getDirectorUrl()],
+            ],
+            "IfW-StableRepository" => [
+                "Values" => ["https://packages.icinga.com/IcingaForWindows/stable"],
+            ]
+        ];
+
+        $script = "[Net.ServicePointManager]::SecurityProtocol = 'tls12, tls11';\n"
+            . "\$ProgressPreference                         = 'SilentlyContinue';" . "\n"
+            . "[string]\$ScriptFile                         = 'C:\Users\Public\IcingaForWindows.ps1';\n"
+            . "\n"
+            . "Invoke-WebRequest `\n    "
             . $this->renderPowershellParameters([
-                'DirectorUrl'            => $this->getDirectorUrl(),
-                'SelfServiceAPIKey'      => $token,
-                'UseDirectorSelfService' => 1,
-                'OverrideDirectorVars'   => 0,
-                'Reconfigure',
-                'RunInstaller'
+                'UseBasicParsing',
+                'Uri'      => "https://packages.icinga.com/IcingaForWindows/IcingaForWindows.ps1",
+                'OutFile' => '$ScriptFile;',
+            ]) . "\n"
+            . "\n"
+            . "& \$ScriptFile `\n    "
+            . $this->renderPowershellParameters([
+                'ModuleDirectory'  => "C:\Program Files\WindowsPowerShell\Modules\\",
+                'InstallCommand'   => json_encode($ifwParams, JSON_UNESCAPED_SLASHES),
+                'IcingaRepository' => "https://packages.icinga.com/IcingaForWindows/stable/ifw.repo.json"
             ]);
 
         return $script;
@@ -235,6 +254,8 @@ class AgentWizard
             $ret .= implode(', ', $vals);
         } elseif (is_int($value)) {
             $ret .= $value;
+        } elseif (is_string($value) && $value[0] === '$') {
+            $ret .= $value;
         } else {
             $ret .= $this->renderPowershellString($value);
         }
@@ -267,7 +288,7 @@ class AgentWizard
         }
 
         return $this->replaceBashTemplate($script, [
-            'ICINGA2_NODENAME'         => $this->getCertName(),
+            'ICINGA2_NODENAME'         => $this->host->getEndpointName(),
             'ICINGA2_CA_TICKET'        => $this->getTicket(),
             'ICINGA2_PARENT_ZONE'      => $this->getParentZone()->getObjectName(),
             'ICINGA2_PARENT_ENDPOINTS' => $endpoints,
@@ -297,7 +318,7 @@ class AgentWizard
             } else {
                 $value = escapeshellarg($value);
             }
-            $script = preg_replace("~^#?$quotedKey='@$quotedKey@'$~m", "${key}=${value}", $script);
+            $script = preg_replace("~^#?$quotedKey='@$quotedKey@'$~m", "{$key}={$value}", $script);
         }
 
         return $script;
