@@ -2,14 +2,17 @@
 
 namespace Icinga\Module\Director\Objects;
 
-use Icinga\Module\Director\IcingaConfig\IcingaConfig;
+use Icinga\Module\Director\Db;
+use Icinga\Module\Director\DirectorObject\Automation\ExportInterface;
+use Icinga\Module\Director\Exception\DuplicateKeyException;
 
-class IcingaUser extends IcingaObject
+class IcingaUser extends IcingaObject implements ExportInterface
 {
     protected $table = 'icinga_user';
 
     protected $defaultProperties = array(
         'id'                    => null,
+        'uuid'                  => null,
         'object_name'           => null,
         'object_type'           => null,
         'disabled'              => 'n',
@@ -21,6 +24,8 @@ class IcingaUser extends IcingaObject
         'zone_id'               => null,
     );
 
+    protected $uuidColumn = 'uuid';
+
     protected $supportsGroups = true;
 
     protected $supportsCustomVars = true;
@@ -43,8 +48,8 @@ class IcingaUser extends IcingaObject
         'zone'   => 'IcingaZone',
     );
 
-    public function getRenderingZone(IcingaConfig $config = null)
+    public function getUniqueIdentifier()
     {
-        return $this->connection->getMasterZoneName();
+        return $this->getObjectName();
     }
 }
