@@ -8,6 +8,10 @@ class PropertyModifierUppercase extends PropertyModifierHook
 {
     public function transform($value)
     {
+        if ($value === null) {
+            return null;
+        }
+
         return \mb_strtoupper($value, 'UTF-8');
     }
 }
