@@ -108,11 +108,11 @@ class CustomvarVariantsTable extends ZfQueryBasedTable
         $columns["cnt_$type"] = 'COUNT(*)';
         $columns['format'] = 'v.format';
         return $db->select()->from(
-            ['v' => "icinga_${type}_var"],
+            ['v' => "icinga_{$type}_var"],
             $columns
         )->join(
-            ['o' => "icinga_${type}"],
-            "o.id = v.${type}_id",
+            ['o' => "icinga_{$type}"],
+            "o.id = v.{$type}_id",
             []
         )->where(
             'v.varname = ?',
