@@ -2,15 +2,16 @@
 
 namespace Icinga\Module\Director\Web\Widget;
 
-use dipl\Html\HtmlDocument;
-use Icinga\Module\Director\Core\CoreApi;
+use Icinga\Module\Director\Db\Branch\Branch;
+use ipl\Html\HtmlDocument;
+use Icinga\Module\Director\Core\DeploymentApiInterface;
 use Icinga\Module\Director\Db;
 use Icinga\Module\Director\Forms\DeployConfigForm;
 use Icinga\Module\Director\IcingaConfig\IcingaConfig;
-use dipl\Html\Html;
-use dipl\Html\Link;
-use dipl\Translation\TranslationHelper;
-use dipl\Web\Widget\NameValueTable;
+use ipl\Html\Html;
+use gipfl\IcingaWeb2\Link;
+use gipfl\Translation\TranslationHelper;
+use gipfl\IcingaWeb2\Widget\NameValueTable;
 
 class DeployedConfigInfoHeader extends HtmlDocument
 {
@@ -25,18 +26,23 @@ class DeployedConfigInfoHeader extends HtmlDocument
     /** @var Db */
     protected $db;
 
-    /** @var CoreApi */
+    /** @var DeploymentApiInterface */
     protected $api;
 
+    /** @var Branch */
+    protected $branch;
+
     public function __construct(
         IcingaConfig $config,
         Db $db,
-        CoreApi $api,
+        DeploymentApiInterface $api,
+        Branch $branch,
         $deploymentId = null
     ) {
         $this->config = $config;
         $this->db     = $db;
         $this->api    = $api;
+        $this->branch = $branch;
         if ($deploymentId) {
             $this->deploymentId = (int) $deploymentId;
         }
@@ -49,13 +55,17 @@ class DeployedConfigInfoHeader extends HtmlDocument
     protected function assemble()
     {
         $config = $this->config;
-        $deployForm = DeployConfigForm::load()
-            ->setDb($this->db)
-            ->setApi($this->api)
-            ->setChecksum($config->getHexChecksum())
-            ->setDeploymentId($this->deploymentId)
-            ->setAttrib('class', 'inline')
-            ->handleRequest();
+        if ($this->branch->isBranch()) {
+            $deployForm = null;
+        } else {
+            $deployForm = DeployConfigForm::load()
+                ->setDb($this->db)
+                ->setApi($this->api)
+                ->setChecksum($config->getHexChecksum())
+                ->setDeploymentId($this->deploymentId)
+                ->setAttrib('class', 'inline')
+                ->handleRequest();
+        }
 
         $links = new NameValueTable();
         $links->addNameValueRow(
